==> pass_mtx-0.0.20.tar.gz: lib/pass_mtx.dart <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'pass_mtx_platform_interface.dart';

class PassMtx {
  Future<String?> getPlatformVersion() {
    return PassMtxPlatform.instance.getPlatformVersion();
  }

  /// Check Pass backend
  Future<String?> getPassPing() {
    return PassMtxPlatform.instance.getPassPing();
  }

  /// Pass Native Version
  Future<String?> getPassVersion() {
    return PassMtxPlatform.instance.getPassVersion();
  }

  /// Initialize PassMtx
  Future<String?> init(
      String appId, String clientId, String privatePem, String publicPem) {
    return PassMtxPlatform.instance
        .init(appId, clientId, privatePem, publicPem);
  }

  /// Initialize PassMtx For Production ENV
  Future<String?> initProd(
      String appId, String clientId, String privatePem, String publicPem) {
    return PassMtxPlatform.instance
        .initProd(appId, clientId, privatePem, publicPem);
  }

  /// Get Card Tokens for User
  Future<String?> getCard(String userId) {
    return PassMtxPlatform.instance.getCard(userId);
  }

  /// Save Card for User
  Future<String?> saveCard(String userId, String szPan, String cvv,
      String expDate, String cardHolderName) {
    return PassMtxPlatform.instance
        .saveCard(userId, szPan, cvv, expDate, cardHolderName);
  }

  /// Verify Saved Card for User
  Future<String?> verifyCard(
      String userId, String verificationMethod, String verficationValue) {
    return PassMtxPlatform.instance
        .verifyCard(userId, verificationMethod, verficationValue);
  }

  /// Delete Card Tokens for User
  Future<String?> deleteCard(String userId) {
    return PassMtxPlatform.instance.deleteCard(userId);
  }

  /// Purchase Request
  Future<String?> makePassPurchase(
      String userId,
      String orderId,
      String paymentToken,
      String expDate,
      String paymentAmount,
      String dbRefNo,
      String description) {
    return PassMtxPlatform.instance.purchase(userId, orderId, paymentToken,
        expDate, paymentAmount, dbRefNo, description);
  }

  /// Pass Get CPM qr code
  Future<String?> passGetQr(String userId, String orderId, String payToken,
      String expDate, String ttl) {
    return PassMtxPlatform.instance
        .passGetQr(userId, orderId, payToken, expDate, ttl);
  }

  /// Pass Check Order Status
  Future<String?> orderEnquery(String userId, String orderId) {
    return PassMtxPlatform.instance.orderEnquery(userId, orderId);
  }

  /// Order Confirmation
  Future<String?> orderConfirm(String userId, String orderId) {
    return PassMtxPlatform.instance.orderConfirm(userId, orderId, "", "");
  }

  /// Order Cancel
  Future<String?> orderCancel(String userId, String orderId) {
    return PassMtxPlatform.instance.orderCancel(userId, orderId);
  }
}

==> pass_mtx-0.0.21.tar.gz: lib/pass_mtx.dart <==
/*
#################################################################################
#                                                                               #
#                     COPYRIGHT (C) DATABANK LLC since 2017                     #
#                                                                               #
#          ALL RIGHTS RESERVED BY DATABANK LLC.  THIS PROGRAM MUST BE           #
#          USED SOLELY FOR THE PURPOSES OF DATABANK LLC AND ITS USERS.          #
#   NO PART OF THIS PROGRAM MAY BE MODIFIED IN SOURCE OR BINARY FORM BY OTHERS  #
#             WITHOUT THE PRIOR WRITTEN PERMISSION OF DATABANK LLC.             #
#                                                                               #
#     USE OF COPYRIGHT NOTICE DOES NOT EVIDENCE PUBLICATION OF THE PROGRAM.     #
#                                                                               #
#################################################################################
*/

import 'pass_mtx_platform_interface.dart';

class PassMtx {
  Future<String?> getPlatformVersion() {
    return PassMtxPlatform.instance.getPlatformVersion();
  }

  /// Check Pass backend
  Future<String?> getPassPing() {
    return PassMtxPlatform.instance.getPassPing();
  }

  /// Pass Native Version
  Future<String?> getPassVersion() {
    return PassMtxPlatform.instance.getPassVersion();
  }

  /// Initialize PassMtx
  Future<String?> init(
      String appId, String clientId, String privatePem, String publicPem) {
    return PassMtxPlatform.instance
        .init(appId, clientId, privatePem, publicPem);
  }

  /// Initialize PassMtx For Production ENV
  Future<String?> initProd(
      String appId, String clientId, String privatePem, String publicPem) {
    return PassMtxPlatform.instance
        .initProd(appId, clientId, privatePem, publicPem);
  }

  /// Get Card Tokens for User
  Future<String?> getCard(String userId) {
    return PassMtxPlatform.instance.getCard(userId);
  }

  /// Save Card for User
  Future<String?> saveCard(String userId, String szPan, String cvv,
      String expDate, String cardHolderName) {
    return PassMtxPlatform.instance
        .saveCard(userId, szPan, cvv, expDate, cardHolderName);
  }

  /// Verify Saved Card for User
  Future<String?> verifyCard(
      String userId, String verificationMethod, String verficationValue) {
    return PassMtxPlatform.instance
        .verifyCard(userId, verificationMethod, verficationValue);
  }

  /// Delete Card Tokens for User
  Future<String?> deleteCard(String userId) {
    return PassMtxPlatform.instance.deleteCard(userId);
  }

  /// Purchase Request
  Future<String?> makePassPurchase(
      String userId,
      String orderId,
      String paymentToken,
      String expDate,
      String paymentAmount,
      String dbRefNo,
      String description) {
    return PassMtxPlatform.instance.purchase(userId, orderId, paymentToken,
        expDate, paymentAmount, dbRefNo, description);
  }

  /// Pass Get CPM qr code
  Future<String?> passGetQr(String userId, String orderId, String payToken,
      String expDate, String ttl) {
    return PassMtxPlatform.instance
        .passGetQr(userId, orderId, payToken, expDate, ttl);
  }

  /// Pass Check Order Status
  Future<String?> orderEnquery(String userId, String orderId) {
    return PassMtxPlatform.instance.orderEnquery(userId, orderId);
  }

  /// Order Confirmation
  Future<String?> orderConfirm(
      String userId,
      String orderId,
      String confirmMethod,
      String confirmResult,
      String payToken,
      String expDate) {
    return PassMtxPlatform.instance.orderConfirm(
        userId, orderId, confirmMethod, confirmResult, payToken, expDate);
  }

  /// Order Cancel
  Future<String?> orderCancel(String userId, String orderId) {
    return PassMtxPlatform.instance.orderCancel(userId, orderId);
  }
}
